#
# spec file for package OpenImageIO
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define so_ver 1_7
Name:           OpenImageIO
Version:        1.7.0dev
Release:        31.2
Summary:        Library for Reading and Writing Images
License:        BSD-3-Clause
Group:          Productivity/Graphics/Other
Url:            http://www.openimageio.org/
#DL-URL: https://github.com/OpenImageIO/oiio/archive/Release-%%{version}/OpenImageIO-%%{version}.tar.gz
Source0:        oiio-Release-%{version}.tar.bz2
Patch0:         oiio-clusterfit-boundscheck.patch
Patch1:         oiio-detectplatform-others.patch
Patch2:         oiio_gcc6_missleading_indentation.patch
# NOTE: Please don't uncomment a build requirement unless you have submitted the package to factory and it exists
#BuildRequires:  Field3D-devel
BuildRequires:  OpenColorIO-devel
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  freetype2-devel
BuildRequires:  giflib-devel
BuildRequires:  glew-devel
BuildRequires:  hdf5-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libopenssl-devel
BuildRequires:  libpng-devel
BuildRequires:  libqt4-devel
BuildRequires:  libraw-devel
BuildRequires:  libtiff-devel
BuildRequires:  libwebp-devel
BuildRequires:  opencv-devel
BuildRequires:  openjpeg-devel
BuildRequires:  openjpeg2-devel
BuildRequires:  pugixml-devel
BuildRequires:  python-devel
# NOTE: txt2man is needed for the man pages but not in factory.
BuildRequires:  txt2man
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} > 1220
BuildRequires:  ilmbase-devel
%else
BuildRequires:  libilmbase-devel
%endif
%if 0%{?suse_version} > 1220
BuildRequires:  openexr-devel
%else
BuildRequires:  OpenEXR-devel
%endif

%description
OpenImageIO is a library for reading and writing images, and a bunch of related
classes, utilities, and applications. There is a particular emphasis on formats
and functionality used in professional, large-scale animation and visual
effects work for film. OpenImageIO is used extensively in animation and VFX
studios all over the world, and is also incorporated into several commercial
products.

%package devel
Summary:        Development Files for OpenImageIO
Group:          Development/Libraries/C and C++
Requires:       libOpenImageIO%{so_ver} = %{version}
Requires:       libOpenImageIO_Util%{so_ver} = %{version}

%description devel
This package provides development libraries and headers needed to build
software using OpenImageIO.

%package -n libOpenImageIO%{so_ver}
Summary:        Library for Reading and Writing Images
Group:          System/Libraries

%description -n libOpenImageIO%{so_ver}
OpenImageIO is a library for reading and writing images, and a bunch of related
classes, utilities, and applications. There is a particular emphasis on formats
and functionality used in professional, large-scale animation and visual
effects work for film. OpenImageIO is used extensively in animation and VFX
studios all over the world, and is also incorporated into several commercial
products.

%package -n libOpenImageIO_Util%{so_ver}
Summary:        Library for Reading and Writing Images
Group:          System/Libraries

%description -n libOpenImageIO_Util%{so_ver}
OpenImageIO is a library for reading and writing images, and a bunch of related
classes, utilities, and applications. There is a particular emphasis on formats
and functionality used in professional, large-scale animation and visual
effects work for film. OpenImageIO is used extensively in animation and VFX
studios all over the world, and is also incorporated into several commercial
products.

%package -n python-OpenImageIO
Summary:        Python Bindings for OpenImageIO
Group:          Development/Libraries/Python
%py_requires

%description -n python-OpenImageIO
This package contains python bindings for OpenImageIO.

%prep
%setup -q -n oiio-Release-%{version}
%patch0
%patch1
%patch2 -p1

# Make sure that bundled libraries are not used
rm -f src/include/pugiconfig.hpp \
      src/include/pugixml.hpp
rm -rf src/include/tbb/

%build
# This is for build debugging purposed
export OIIOINC=`echo $PWD`
%define pwd $OIIOINC
%define oiioinclude %{pwd}/src/include
echo %{pwd}
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
mkdir -p build
cd build
cmake \
%ifarch ppc
    -DNOTHREADS=ON \
%endif
    -DCMAKE_INSTALL_PREFIX=%{_prefix} \
    -DLIB_INSTALL_DIR=%{_libdir} \
    -DPYLIB_INSTALL_DIR=%{python_sitearch} \
    -DINSTALL_DOCS:BOOL=ON \
    -DDOC_INSTALL_DIR=%{_docdir}/%{name} \
    -DINSTALL_FONTS:BOOL=ON \
    -DBUILDSTATIC:BOOL=OFF \
    -DLINKSTATIC:BOOL=OFF \
    -DUSE_EXTERNAL_PUGIXML:BOOL=ON \
    -DUSE_FFMPEG:BOOL=OFF \
    -DUSE_OPENSSL:BOOL=ON \
    -DCMAKE_SKIP_RPATH:BOOL=ON \
    -DUSE_OPENCV:BOOL=OFF \
        ..
make %{?_smp_mflags} VERBOSE=1 || \
make -j1 VERBOSE=1
cd ..
make %{?_smp_mflags} doxygen

%install
%make_install -C build

# Move devel documentation to the right location
mkdir -p %{buildroot}%{_docdir}/%{name}-devel
mv %{buildroot}%{_docdir}/%{name}/openimageio.pdf %{buildroot}%{_docdir}/%{name}-devel/
%if 1 == 0
# Install additional devel documentation
cp -a src/doc/doxygen/html/ %{buildroot}%{_docdir}/%{name}-devel/
%endif

%fdupes -s %{buildroot}

%post -n libOpenImageIO%{so_ver} -p /sbin/ldconfig

%postun -n libOpenImageIO%{so_ver} -p /sbin/ldconfig

%post -n libOpenImageIO_Util%{so_ver} -p /sbin/ldconfig

%postun -n libOpenImageIO_Util%{so_ver} -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc CHANGES CREDITS LICENSE README.rst
%{_bindir}/*
%dir %{_datadir}/fonts/oiio
%{_datadir}/fonts/oiio/DroidSans-Bold.ttf
%{_datadir}/fonts/oiio/DroidSans.ttf
%{_datadir}/fonts/oiio/DroidSansMono.ttf
%{_datadir}/fonts/oiio/DroidSerif-Bold.ttf
%{_datadir}/fonts/oiio/DroidSerif-BoldItalic.ttf
%{_datadir}/fonts/oiio/DroidSerif-Italic.ttf
%{_datadir}/fonts/oiio/DroidSerif.ttf
%if 1 == 1
%{_mandir}/man1/*.1%{ext_man}
%endif

%files devel
%defattr(-,root,root,-)
%doc %{_docdir}/%{name}-devel/
%{_includedir}/OpenImageIO/
%{_libdir}/*.so

%files -n libOpenImageIO%{so_ver}
%defattr(-,root,root,-)
%{_libdir}/libOpenImageIO.so.*

%files -n libOpenImageIO_Util%{so_ver}
%defattr(-,root,root,-)
%{_libdir}/libOpenImageIO_Util.so.*

%files -n python-OpenImageIO
%defattr(-,root,root,-)
%{python_sitearch}/OpenImageIO.so

%changelog
* Fri Jun 17 2016 normand@linux.vnet.ibm.com
- Added oiio_gcc6_missleading_indentation.patch tracked upstream
  https://github.com/OpenImageIO/oiio/pull/1436
  and remove just added flag. See boo#985370
- Removed previous work around for the bug.
* Fri Jun 17 2016 davejplater@gmail.com
- Fix gcc6 build with -Wno-error=misleading-indentation flag, see
  boo#985370
* Tue Mar 22 2016 normand@linux.vnet.ibm.com
- do not set -DNOTHREADS=ON for ppc64 to avoid build error
* Sun Mar 13 2016 davejplater@gmail.com
- Disable opencv until the build problem is resolved
* Thu Jan 14 2016 davejplater@gmail.com
- Update to release 1.7.0dev
- Explicitly enabled build with openssl because the build fails on
  i586 due to internally defined types.
- Upstream changes:
  Major new features and improvements:
  Public API changes:
  * DeepData internals and API overhaul: struct internals hidden, now you
  must use the API; DeepData declaration is now in deepdata.h, not in
  imageio.h; DD methods now allow insertion and erasure of individual
  samples. #1289 (1.7.0)
  * imageio.h: Removed items deprecated since 1.4: a version of
  convert_types() that took alpha and z channel indices
  (but never used them). #1291
  * fmath.h: Removed safe_sqrtf, safe_acosf, fast_expf, which have been
  deprecated since 1.5. (1.7.0) #1291
  * Removed ImageBufAlgo::flipflop(), which was deprecated since 1.5 and
  is now called rotate180. #1291 (1.7.0)
  * Several varieties of ImageCache and TextureSystem getattribute methods
  were noticed to not be properly declared 'const'. This was fixed.
  [#1300] (1.7.0/1.6.9)
  Fixes, minor enhancements, and performance improvements:
  * oiiotool:
  * oiiotool --subimage now takes as an argument either the subimage
    numeric index, or a subimage name. #1287 (1.7.0)
  * oiiotool's image cache was smaller than intended because of typo.
    (1.7.0/1.6.9)
  * ImageBufAlgo:
  * The varieties of add(), sub(), mul(), and div() that take an
    image operand and a per-channel constant operand have all been
    modified to work properly for "deep" images. #1297 (1.7.0)
  * maketx:
  * maketx -u now remakes the file if command line arguments or OIIO
    version changes, even if the files' dates appear to match.
    [#1281] (1.7.0)
  * TIFF:
  * When outputting a TIFF file, a special attribute "tiff:half", if
    set to nonzero, will enable writing of 16-bit float pixel data
    (obviously, only if the spec.format is HALF). #1283 (1.7.0)
  * TIFF input: erase redundant IPTC:Caption and IPTC:OriginatingProgram
    if they are identical to existing ImageDescription and Software
    metadata, respectively. (1.7.0/1.6.9)
  * Video formats:
  * The ffmpeg-based reader had a variety of fixes. #1288 (1.7.0)
  Build/test system improvements:
  * Fix build break against Boost 1.60. #1299,#1300 (1.7.0/1.6.9/1.5.23)
  * filesystem_test now much more comprehensively tests the contents of
  Filesystem. #1302 (1.7.0)
  * fmath_test adds benchmarks for various data conversions. #1305 (1.7.0)
  Developer goodies / internals:
  * parallel_image has been improved in several ways: can choose split
  direction; raised minimum chunk size to prevent thread fan-out for
  images too small to benefit; uses the calling thread as part of the
  pool. #1303 (1.7.0)
  * timer.h: DoNotOptimize() and clobber() help to disable certain
  optimizations that would interfere with micro-benchmarks. #1305 (1.7.0)
  * simd.h improvements: select(); round(); float4::store(half*),
  int4::store(unsigned short*), int4::store(unsigned char*). #1305 (1.7.0)
  * fmath.h: convert_types has new special cases that vastly speed up
  float <-> uint16, uint8, and half buffer conversions. #1305 (1.7.0)
* Mon Jan 11 2016 davejplater@gmail.com
- Update to release 1.6.9
- Upstream changes:
  Release 1.6.9 (released 5 Jan 2016 -- compared to 1.6.8)
  * Several varieties of ImageCache and TextureSystem getattribute
    methods were noticed to not be properly declared 'const'.
    This was fixed. #1300 (1.6.9)
  * Fix build break against Boost 1.60. #1299,#1300 (1.6.9/1.5.23)
  * The Python bindings for ImageCache was overhauled after several
    of the methods were found to be horribly broken. #1300 (1.6.9)
  * oiiotool --subimage now allows a subimage name as argument, as
    well as the numeric index. #1271,#1287 (1.6.9)
  * TIFF input: erase redundant IPTC:Caption and IPTC:OriginatingProgram
    if they are identical to existing ImageDescription and Software
    metadata, respectively. (1.6.9)
  * Fix oiiotool image cache smaller than intended because of typo.
- See /usr/share/doc/packages/OpenImageIO/Changes for changes since
  1.5.20
* Thu Nov 19 2015 davejplater@gmail.com
- Recommented Field3D build requirement.
* Sat Nov 14 2015 hpj@urpla.net
- download, verify and recompress _service added
- Release 1.5.20
  * Nuke plugin: don't crash with NULL Knob* in TxReaderFormat::setMipLabels.
    [#1212]
  * Fix build warnings for new Apple tools release that upgrades the standard
    clang release. #1218
  * Make TIFF reader robust to strange TIFF files that have unexpected MIP
    level-to-MIP level changes in planarconfig, photometric, palette,
    extrasamples, etc. We previously assumed these things would never vary
    between MIP levels of the same file, and Murphy called our bluff. #1220,1221
- Release 1.5.19
  * Fix compile warnings on some platforms/compilers.
  * Fix build break with certain new versions of libraw. #1204
  * Internals: Timer and ScopedTimer have changed slightly. This isn't used
    in any public OIIO APIs, but may affect 3rd party programs that like
    to use OIIO's timer.h for convenience. #1201
  * Internals: dassert.h has added OIIO_STATIC_ASSERT macros for static
    assertion. Doesn't affect existing OIIO apps since they are new
    additions, but feel free to use them! #1202
- Release 1.5.18
  * PSD input improvements: better error handling for files lacking "global
    layer mask info" or "additional layer info"; additional PSD signatures
    for global additional layer info; better error handling when dealing
    with an empty layer mask. #1147
  * TIFF output: recognize special "tiff:write_exif" metadata, which when
    present and set to 0, will skip writing the Exif directory into the TIFF
    file. This can be helpful when you expect the resulting TIFF file to be
    read with very old versions of libtiff. #1185
  * Top-level Makefile option USE_OPENCV=0 to turn off even searching for
    OpenCV components. #1194
- Release 1.5.17
  * Fix support for older ffmpeg version on Ubuntu 14.04. #1168
  * Fix bug in fft -- was not always zeroing out the imaginary channel. #1171
  * Build-time fixes for Nocona CPUs that have SSE3 without SSSE3. #1175
  * ustring fixes for new gcc (5.1+) and new std::string ABI. #1176
  * Fixes for unit test timer_test for new OSX versions with timer
    coalescing. #1181
  * Fix bugs with rangecompress and rangeexpand when using luma. #1180
  * Fixes for clean build when using clang 3.6. #1182
- Release 1.5.16
  * PNG writes now honor PixelAspectRatio attribute. #1142
  * Build fixes for Visual Studio 2010 #1140
  * PSD & JPEG plugins fixes for Win32 compilation.
  * Also search for OIIO plugins in [DY]LD_LIBRARY_PATH. #1153
  * Give Strutil::parse_string an option to not strip surrounding quotes.
  * Fix Nuke plugin build files to not do anything if USE_NUKE=0  #1156
  * New ImageInput query: "procedural" -- returns 1 if the ImageInput may
    not correspond to an actual file. #1154
  * TypeDesc has a new constructor and fromstring of a string_view, in
    addition to the old versions that took char*. #1159
  * Eliminate spurious ImageCache invalidation just because the shared
    cache is requested again. #1157
  * Fixed trilinear MIPmap texture lookups that gave invalid alpha fill. #1163
  * Filesystem: sequence matching should clear results arrays upon start.
- Release 1.5.15
  * Bug fix with IBA::channels() with deep data with UINT channels.
  * Fix TypeDesc compatibility with OSL.
  * Misc WIN32 / VS2010 fixes.
  * Fix incorrect logic in convert_image with certain channel types and
    strides. #1144
- Release 1.5.14
  * fmath: save_fast_pow improves the precision of its results for
    special cases of pow(x,1) and pow(x,2). #1094 (1.5.13)
  * Fix warnings when compiling with C++11. (1.5.13)
  * Dont link Python framework on OSX. #1099 (1.5.13)
  * Improve IBA::compare() (and therefore oiiotool -diff and idiff) when
    the images being compared have NaN or Inf values. #1109 (1.5.13)
  * TextureSystem bug fix that occasionally resulted in NaN in the alpha
    channel result when looking up from 3-channel images. #1108 (1.5.13)
  * Added TypeDesc::TypeHalf(). #1113 (1.5.13)
  * Fix IBA::channels() bugs when dealing with "deep" images. #1113 (1.5.13)
  * Python ImageSpec.set_channel_formats() now works when the channel
    type lists are either TypeDesc, in addition to the existing support
    for BASETYPE. #1113 (1.5.13)
  * Added Python bindings for DeepData and deep reads (ImageInput) and
    writes (ImageOutput). #1113 (1.5.13)
  * Fix bugs in reading deep OpenEXR images with mixed channel types.
    [#1113] (1.5.13)
  * Fix bug in IBA::convolve() for the case when the kernel image passed
    is not a float image. #1116 (1.5.13)
- Release 1.5.13
  * oiiotool: Bug fix for frame sequences -- could crash in Windows. #1060
  * New ImageOutput::supports() tags: supports("alpha") should be true for
    image formats that support an alpha channel, supports("nchannels") should
    be true for output formats that support an arbitrary number of output
    channels. #1058
  * oiiotool: Gracefully handle requests to save an image with more channels
    than the output file format can handle. Instead of being a fatal error,
    now it's just a warning, and extra channels are dropped. It tries to
    to find R, G, B, and A channels, saving them. If those names are
    not found, it just saves the first 3 (or 4) channels. #1058
  * Improved handling of "PixelAspectRatio" for JPEG, TIFF, and OpenEXR.
    [#1042] #1066
  * oiiotool: Improve error messages when files can't be read. It is now
    easier to to distinguish files that don't exist from those that
    are an unknown format from those that are corrupted or have read
    errors. #1065
  * maketx now writes to a temporary file, then moving it to the final
    requested output filename only when the write completed without error.
    This prevents situations where maketx crashes or is killed and leaves
    behind a file that looks correct but is actually corrupted or
    truncated. #1072
  * Python: added previously-M.I.A. ImageSpec.erase_attribute(). #1063
  * Add Filesystem::rename() utility. #1070
  * Made TypeDesc::equivalent accept comparisons of arrays of unspecified
    length with ones of definite length. #1072
  * oiiotool & maketx have improved error message when unknown data format
    names are requested with "-d". #1077
  * oiiotool numeric wildcard improvement: allow more digits to match. #1082
  * Remove dependency of OpenSSL by default. #1086
* Thu May 28 2015 ro@suse.de
- added patch oiio-detectplatform-others.patch
  to fix build on other architectures
- added patch oiio-clusterfit-boundscheck.patch
  to fix build failure on aarch64, looks like compiler is smarter
* Sat Feb 28 2015 davejplater@gmail.com
- Update to version 1.5.12 and prepare for factory to enable blender
  to build with cycles, see bnc#905649
- Many new features - See /usr/src/doc/packages/OpenImageIO/CHANGES
* Sun Oct 27 2013 asterios.dramis@gmail.com
- Update to version 1.2.2:
  * New features:
    + New oiiotool --siappend : append subimages of top two images on stack.
    + Utilities: added Strutil::contains() and icontains().
  * Fixes:
    + Fixes in handling XMP & IPTC metadata.
    + oiiotool --origin and --fullpixels did not correctly propagate their
    changes to the output images.
    + oiiotool --colorconvert (and the underlying ImageBufAlgo::colorconvert)
    could crash if given a color conversion recognized as a no-op.
    + DPX output could crash when writing crop images.
    + DPX input was not recognizing the proper image offset or originalsize.
    + oiiotool --fit wasn't padding correctly or modifying offsets properly.
  * Build fixes:
    + Fix compiler error on MIPS platform.
    + Add FIELD3D_HOME description to 'make help'
    + Always use the HDF5 release libraries (for Field3D), not the debug ones.
  From version 1.2.1:
  * oiiotool: Fix memory leak when processing frame range.
  * Docs improvement: full documentation of ImageBufAlgo.
  * oiiotool --help now returns a success error code, not a failure.
  * oiiotool: fix incorrect help message about --ociolook.
  * oiiotool: Fix typo in "oiio:Colorspace" attribute name that interfered
    with correct color space conversion in --colorconvert.
  * Many fixes for compiler warnings on various platforms: fmath_test.cpp,
    field3dinput.cpp, sysutil.cpp, argparse.cpp, oiiotool.cpp.
  * Fixes problems on little-endian architecture with texture3d.cpp.
  * Fix compilation problems on architectures with gcc, but no 'pause'
    instruction.
  * Fix build search path for correctly finding libopenjpeg 1.5.
  * Work around bug in older MSVC versions wherein Filesystem::open needed
    to explicitly seek to the beginning of a file.
  * Build fixes for FreeBSD.
  * Fix testsuite/oiiotool on Windows -- windows shell doesn't expand
    wildcards.
- Removed oiio-typedef.patch (fixed upstream).
- Rebased oiio-ppc.patch and oiio-arm.patch to apply cleanly.
- Added an upstream patch (hdf5_libs.patch) to fix linking with HDF5 libs.
* Tue Aug  6 2013 asterios.dramis@gmail.com
- BuildRequire OpenColorIO-devel only for openSUSE > 12.3.
* Tue Aug  6 2013 asterios.dramis@gmail.com
- Update to version 1.2.0:
  * Major new release.
  * Lots of changes (See CHANGES files).
- Replaced OpenImageIO-ppc.patch with oiio-ppc.patch (taken from Fedora).
- Added a patch (oiio-arm.patch) to fix compilation with arm (taken from
  Fedora).
- Added a patch (oiio-typedef.patch) to fix compiler warning about unused local
  typedef (fix for gcc-4.8) (taken from Fedora).
- Added freetype2-devel and libopenssl-devel build requirements.
- Removed tbb-devel build requirement (deprecated).
- Use -DCMAKE_SKIP_RPATH=ON to fix compilation.
* Sun Jun  9 2013 asterios.dramis@gmail.com
- Update to version 1.1.11:
  * IFF input: bug in endian swap of 16 bit IFF files.
  * oiiotool: fix a minor bug where tiled files were output inappropriately.
    (Had been patched in master some time ago.)
  * fmath.h additions: safe_inversesqrt, safe_log, safe_log2, safe_log10,
    safe_logb.  These are versions that clamp their inputs so that they
    can't throw exceptions or return Inf or NaN.
  * Fix to not incorrectly print ImageCache stats for certain broken files.
  From version 1.1.10:
  * IBA::fillholes() and oiiotool --fillholes can smoothly fill in alpha
    holes with nearby colors. Great for extrapolating the empty areas of
    texture atlas images so that filtered texture lookups pull in a plausible
    color at part edges.
  * IBA::clamp and oiiotool --clamp clamp pixel values to a scalar or
    per-channel min and/or max, or clamp alpha to [0,1].
  * IBA::rangecompress()/rangeexpand(), and oiiotool --rangecompress /
  - -rangeexpand compress the excess >1 values of HDR images to a log
    scale (leaving the <= 1 part linear), and re-expand to the usual
    linear scale.  This is very helpful to reduce ringing artifacts that
    can happen when an HDR image is resized with a good filter with negative
    lobes (such as lanczos3), by doing a range compression, then the resize,
    then range expansion. It's not mathematically correct and loses energy,
    but it often makes a much more pleasing result.
  * maketx --hicomp does highlight compression -- automatically doing a
    range compress before each high-quality resize step, and then a
    range expansion and clamp-to-zero (squash negative pixels) after
    each resize.
  * DPX - when writing DPX files, properly set the pixel aspect ratio.
  From version 1.1.9:
  * IBA::resize and oiiotool --resize/--fit: Bug fixes to resize filter
    size selection fix artifacts wherein extreme zooms could end up with
    black stripes in places where the filters fell entirely between samples.
  * oiiotool --fit: fix subtle bugs with aspect ratio preservation for
    images with differing data and display windows; and allow "filter=..."
    to override the default filter used for fit.
  * Resize improvement: fix potential artifacts at the image edges resulting
    from odd clamping behavior.
  * Even more frame range wildcard flexibility with oiiotool --frames and
  - -framepadding options.
  * oiiotool --resize and --fit (and the underlying IBA::resize()) have been
    sped up significantly and are now also multithreaded.
  From version 1.1.8:
  * oiiotool --chappend (and ImageBufAlgo::channel_append() underneath) allow
    you to take two files and concatenate their color channels.
  * oiiotool --chnames allows you to rename some or all of a file's color
    channels.
  * oiiotool can loop over entire frame ranges by specifying wildcard
    filenames such as "foo.#.tif" or "bar.1-10#.exr".
  * Cmake: OVERRIDE_SHARED_LIBRARY_SUFFIX allows the shared library suffix
    to be overridden (e.g., if you need to force .so names on OSX rather
    than the usual default of .dylib).
  From version 1.1.7:
  * Back out dangerous change to thread.h that was in 1.1.6, which could
    cause performance problems.
  * Compile fix for WIN32 in strutil.cpp
  * Compile fix for Windows XP - add implementation of InterlockedExchangeAdd64
- Added txt2man as build requirement.
* Thu Feb 21 2013 asterios.dramis@gmail.com
- Added OpenColorIO-devel as build requirement.
* Wed Feb 20 2013 asterios.dramis@gmail.com
- Initial rpm release (version 1.1.6).
- Added a patch "OpenImageIO-ppc.patch" to fix compilation with ppc (patch
  taken from Fedora).
